import http from '../utils/http'

const GET_SECTION_SAMPLE_API = '/section/get_section_sample';
const GET_SECTION_A_LIST_API = '/section/get_section_a_list';
export const Get_LOGIN_SMS = '/login_sms';
export const NO_AUTH_API_LIST = [GET_SECTION_SAMPLE_API, GET_SECTION_A_LIST_API, Get_LOGIN_SMS];

//#region ====================== knowledge ======================

export interface KnowledgeRes {
  json_ok: boolean;
  question: string;
  answer_type: string;
  knowledge: KnowledgeData[];
}

export interface KnowledgeData {
  answer: string;
  contexts: Context[];
}

export interface Context {
  page_content: string;
  metadata: Metadata;
}

export interface Metadata {
  Title?: string;
}

//#endregion

//#region ====================== RecordSet ======================
export interface RecordSetRes {
  json_ok: boolean;
  question: string;
  answer_type: string;
  values: RecordSetValues;
}

export interface RecordSetValues {
  names: string[];
  values: Array<Array<any>>;
  type: string;
  title: string;
}

//#endregion
/**
 * @summary 获取历史操作
 */
export const GetHistory = async () => {
  return http.request({
    url: '/chat/get_history',
    method: 'POST',
  });
};

/**
 * @summary
 */
export const GetSampleList = async () => {
  return http.request({
    url: '/chat/get_sample_list',
    method: 'POST',
  });
};

/**
 * @summary description
 */
export const QuestionAi = async (params,extraData={}) => {
  return http.request({
    url: '/chat/question',
    method: 'POST',
    data: params,
    headers: {
      'Content-Type': 'application/x-www-form-urlencoded',
    },
    ...extraData
  });
};

/**
 * @summary description
 */
export const GetLLMList = async () => {
  return http.request({
    url: '/llm/llm/get_llm_list',
    method: 'POST',
  });
};

/**
 * @summary description
 */
export const SetLLM = async (params) => {

  return http.request({
    url: '/llm/set_llm',
    method: 'POST',
    data: params,
    headers: {
      'Content-Type': 'application/x-www-form-urlencoded',
    },
  });
};

/**
 * @summary  获取主场景
 */
export const getSectionList = async () => {
  return http.request({
    url: GET_SECTION_A_LIST_API,
    method: 'POST',
  });
};
/**
 * @summary  根据主应用场景获取次应用场景
 */
export const getSectionByIdList = async (params) => {
  return http.request({
    url: '/section/get_section_b_list',
    method: 'POST',
    data: params,
    headers: {
      'Content-Type': 'application/x-www-form-urlencoded',
    },
  });
};
/**
 * @summary  获取全部次场景
 */
export const getSectionByAllList = async () => {
  return http.request({
    url: '/section/get_section_list',
    method: 'POST',
  });
};
/**
 * @summary description
 */
export const CreateHistoryGroup = async (params,extraData={}) => {
  return http.request({
    url: '/history/create_history_group',
    method: 'POST',
    data: params,
    headers: {
      'Content-Type': 'application/x-www-form-urlencoded',
    },
    ...extraData
  });
};

export const GetHistoryGroups = async (extraData={}) => {
  return http.request({
    url: '/history/get_history_groups',
    method: 'POST',
    headers: {
      'Content-Type': 'application/x-www-form-urlencoded',
    },
    ...extraData
  });
};

export const DeleteHistoryGroups = async (params) => {
  return http.request({
    url: '/history/delete_history_group',
    method: 'POST',
    data: params,
    headers: {
      'Content-Type': 'application/x-www-form-urlencoded',
    },
  });
};

export const QueryHistoryGroup = async (params) => {
  return http.request({
    url: '/history/query_history_detail',
    method: 'POST',
    data: params,
    headers: {
      'Content-Type': 'application/x-www-form-urlencoded',
    },
  });
};

// 获取AI对话测试例子列表
export const getSelectSample = async (params) => {
  return http.request({
    url: GET_SECTION_SAMPLE_API,
    method: 'POST',
    data: params,
    headers: {
      'Content-Type': 'application/x-www-form-urlencoded',
    },
  });
};

export const GetHistoryAnswer = async (params,extraData={}) => {
  return http.request({
    url: '/history/get_history_answer',
    method: 'POST',
    data: params,
    headers: {
      'Content-Type': 'application/x-www-form-urlencoded',
    },
    ...extraData
  });
};

export const QueryHistoryDetail = async (params,extraData={}) => {
  return http.request({
    url: '/history/query_history_detail',
    method: 'POST',
    data: params,
    headers: {
      'Content-Type': 'application/x-www-form-urlencoded',
    },
    ...extraData
  });
};
//系统通知
export const systemNotifyList = async () => {
  return http.request({
    url: '/system/get_sys_notify_list',
    method: 'POST',
  });
};
//获取大模型列表
export const getBigModelList = async () => {
  return http.request({
    url: '/llm/llm/get_llm_list',
    method: 'POST',
  });
};

/**
 * @summary 设置历史对话状态（未设置：NULL，顶1，踩0
 */
export const SetHistoryAnswerState = async (params) => {
  return http.request({
    url: '/history/set_history_answer_state',
    method: 'POST',
    data: params,
    headers: {
      'Content-Type': 'application/x-www-form-urlencoded',
    },
  });
};

/**
 * @summary AI大模型对话
 */
export const QuestionWorkAi = async (params) => {
  return http.request({
    url: '/chat/question1',
    method: 'POST',
    data: params,
    headers: {
      'Content-Type': 'application/x-www-form-urlencoded',
    },
  });
};

/**
 * @summary AI大模型对话
 */
export const getUserTemplateList = async () => {
  return http.request({
    url: '/system/get_user_template_list',
    method: 'POST',
  });
};

/**
 * 查询问题进度
 * @param params
 * @param req
 * @returns
 */
export const getQuestionProcess = async (params,extraData={}) => {
  return http.request({
    url: '/chat/get_question_process',
    method: 'POST',
    data: params,
    headers: {
      'Content-Type': 'application/x-www-form-urlencoded',
    },
    ...extraData
  });
};

export const setHistoryGroupTitle = async (params,extraData={}) => {
  return http.request({
    url: '/history/set_history_group_title',
    method: 'POST',
    data: params,
    headers: {
      'Content-Type': 'application/x-www-form-urlencoded',
    },
    ...extraData
  });
};

export const reportHistoryProblem = async (params) => {
  return http.request({
    url: '/history/report_history_problem',
    method: 'POST',
    data: params,
    headers: {
      'Content-Type': 'application/x-www-form-urlencoded',
    },
  });
};

export const querySimilarityHistory = async (params) => {
  return http.request({
    url: '/history/query_similarity_history',
    method: 'POST',
    data: params,
    headers: {
      'Content-Type': 'application/x-www-form-urlencoded',
    },
  });
};

export const filterQuery = async (params) => {
  return http.request({
    url: '/chat/filter_query',
    method: 'POST',
    data: params,
    headers: {
      'Content-Type': 'application/x-www-form-urlencoded',
    },
  });
};



export const queryScadaTimeValues = async (params) => {
  return http.request({
    url: '/data/query_scada_time_values',
    method: 'POST',
    data: params,
    headers: {
      'Content-Type': 'application/x-www-form-urlencoded',
    },
  });
};


/** @description 关联查询 */
export const extCallQuery = async (params) => {
  return http.request({
    url: '/chat/ext_call_query',
    method: 'POST',
    data: params,
    headers: {
      'Content-Type': 'application/x-www-form-urlencoded',
    },
  });
};